Improve this Doc

# Error: $compile:noctrl
Controller is required.

    Cannot bind to controller without directive '{0}'s controller.

## Description

When using the `bindToController` feature of AngularJS, a directive is required to have a Controller. A controller may be specified by adding a "controller" property to the directive definition object. Its value should be either a string, or an invokable object (a function, or an array whose last element is a function).

For more information, see the directives guide.